@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_plugins.py 12001 2020-03-24 16:45:06Z Trista $
+# $Id: cms_plugins.py 12242 2020-05-20 07:23:17Z Trista $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Trista $
-# $Date: 2020-03-25 00:45:06 +0800 (週三, 25 三月 2020) $
-# $Revision: 12001 $
+# $Date: 2020-05-20 15:23:17 +0800 (週三, 20 五月 2020) $
+# $Revision: 12242 $
 
 import datetime
 
@@ -307,9 +307,11 @@ class CallToActionPlugin(CMSPluginBase):
                 
                 thankNode = TreeNode(site_id=obj.page.node.site_id)
                 lan = obj.language
-                childPage = Page(node=thankNode, template=_settings.THANK_DEFAULT_TEMPLATE, created_by=request.user, languages=lan)
+                childPage = Page(node=thankNode, template=_settings.THANK_DEFAULT_TEMPLATE, created_by=request.user, 
+                                 languages=lan)
                 childPage.save()
-                childTitle = Title(language=lan, title='Thank', slug='thank', page=childPage, path=f'{obj.page.title_set.all()[0].path}/thank')
+                childTitle = Title(language=lan, title='Thank', slug='thank', page=childPage, 
+                                   path=f'{obj.page.title_set.all()[0].path}/thank')
                 childTitle.save()
                 childPage.publish(language=lan)
                 redirectPage = childPage
