@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_plugins.py 12126 2020-04-27 12:30:33Z Lavender $
+# $Id: cms_plugins.py 12209 2020-05-13 07:27:11Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-04-27 20:30:33 +0800 (週一, 27 四月 2020) $
-# $Revision: 12126 $
+# $Date: 2020-05-13 15:27:11 +0800 (週三, 13 五月 2020) $
+# $Revision: 12209 $
 
 import re
 import requests
@@ -80,7 +80,7 @@ def getAuthorizationMsg():
         popupWindow.window.focus();
     })
 </script>
-''' % reverse("facebookAuthorizationRedirect")
+''' % reverse("facebookAccessTokenCreate")
 
     if not getAccessToken():
         accessMessage = _(
