@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 12209 2020-05-13 07:27:11Z Lavender $
+# $Id: views.py 12251 2020-05-20 19:31:27Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,10 +12,12 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-05-13 15:27:11 +0800 (週三, 13 五月 2020) $
-# $Revision: 12209 $
+# $Date: 2020-05-21 03:31:27 +0800 (週四, 21 五月 2020) $
+# $Revision: 12251 $
 
 import json
+import urllib
+import base64
 
 import requests
 
@@ -29,6 +31,7 @@ from django.utils.translation import ugettext as _
 from django.urls import reverse
 
 from Iuppiter.Logging import createLogger
+from Iuppiter.Encryption import Encryptor
 from Zephyrus.facebook import MANAGE_PAGES_STATE, SCOPE
 from Zephyrus.facebook import settings as FBSettings
 from Zephyrus.facebook import getCommentURL, getAPIData
@@ -61,6 +64,22 @@ def createAccessTokenAPIURL(request, code):
            FBSettings.ZEPHYRUS_FACEBOOK_DEFAULT_APP_SECRET, code)
     return url
     
+def encrypt(data):
+    data = json.dumps(data) 
+    encryptor = Encryptor(FBSettings.ZEPHYRUS_FACEBOOK_DEFAULT_SECRET_KEY.encode())
+    secret = encryptor.encrypt(data.encode())  
+    secret = base64.b64encode(secret)
+    secret = urllib.parse.quote(secret)
+    return secret
+    
+def decrypt(secret):
+    encryptor = Encryptor(FBSettings.ZEPHYRUS_FACEBOOK_DEFAULT_SECRET_KEY.encode())
+    secret = urllib.parse.unquote(secret)
+    secret = base64.b64decode(secret.encode())
+    data = encryptor.decrypt(secret)
+    data = json.loads(data)
+    return data
+    
 class FacebookAccessTokenCreateView(View):
 
     def get(self, request, *args, **kwargs):
@@ -71,19 +90,25 @@ class FacebookAccessTokenCreateView(View):
                 request.scheme, request.META['HTTP_HOST'], reverse('facebookAccessTokenReturn'))
             
             # 使用這個 view 需要以下兩種參數
-            data = "redirect=%s&password=%s" % (redirectURL, FBSettings.ZEPHYRUS_FACEBOOK_DEFAULT_PASSWORD)
+            data = {
+                "redirect": redirectURL,
+                "password": FBSettings.ZEPHYRUS_FACEBOOK_DEFAULT_PASSWORD,
+            }
+            secret = encrypt(data)
             
-            return redirect("%s%s?%s" % (
+            return redirect("%s%s?secret=%s" % (
                 FBSettings.ZEPHYRUS_FACEBOOK_DEFAULT_GET_ACCESS_TOKEN_URL, 
-                reverse('facebookAuthorizationRedirect'), data))
+                reverse('facebookAuthorizationRedirect'), secret))
         else:
             raise Http404()
         
 class FacebookAccessTokenReturnView(View):
 
     def get(self, request, *args, **kwargs):
-        accessToken = request.GET.get("token")
-        msg = request.GET.get("msg")
+        secret = request.GET.get("secret")
+        data = decrypt(secret)
+        accessToken = data.get("token")
+        msg = data.get("msg")
         
         if accessToken:
             # save accessToken
@@ -96,9 +121,19 @@ class FacebookAccessTokenReturnView(View):
 class AuthorizationRedirectView(View):
 
     def get(self, request, *args, **kwargs):
-        # 要使用這個 view 需要有 password redirectToURL
-        redirectToURL = request.GET.get("redirect")
-        password = request.GET.get("password")
+        secret = request.GET.get("secret")
+        data = decrypt(secret)
+        redirectToURL = data.get("redirect")
+        password = data.get("password")
+        
+        xForwardedFor = request.META.get('HTTP_X_FORWARDED_FOR')
+        if xForwardedFor:
+            ip = xForwardedFor.split(',')[0]
+        else:
+            ip = request.META.get('REMOTE_ADDR')
+        
+        logger.info("[Iuno.facebook] Someone call FB authorization view: ip=%s data=%s" % (ip, data))
+        
         if redirectToURL and password == FBSettings.ZEPHYRUS_FACEBOOK_DEFAULT_PASSWORD:
             return redirect(createAuthorizationURL(request, redirectToURL=redirectToURL))
         raise Http404()
@@ -133,7 +168,12 @@ class FacebookAuthorizationView(View):
                 logger.error("Can't get access token from facebook API: %s" % e)
                 msg = self.ERROR_MESSAGE
                 
-            redirectToURL = "%s?token=%s&msg=%s" % (redirectToURL, accessToken, msg)
+            data = {
+                "msg": msg,
+                "token": accessToken,
+            }
+            secret = encrypt(data)  
+            redirectToURL = "%s?secret=%s" % (redirectToURL, secret)
             return redirect(redirectToURL)
         raise Http404()
    
